@@ -8,14 +8,14 @@ from tornado.ioloop import IOLoop, PeriodicCallback
 
 from ..core import rpc
 from ..utils import is_kernel, log_errors, key_split
-from ..executor import default_executor
 from ..scheduler import Scheduler
 from ..diagnostics.progress_stream import (task_stream_palette,
         incrementing_index)
 
 try:
     from bokeh.palettes import Spectral11, Spectral9, viridis
-    from bokeh.models import ColumnDataSource, DataRange1d, HoverTool, Range1d
+    from bokeh.models import (ColumnDataSource, DataRange1d, HoverTool,
+            Range1d, value)
     from bokeh.plotting import figure
     from bokeh.io import curstate, push_notebook
 except ImportError:
@@ -33,7 +33,8 @@ def task_stream_plot(sizing_mode='scale_width', **kwargs):
     fig = figure(
         x_axis_type='datetime', title="Task stream",
         tools='xwheel_zoom,xpan,reset,box_zoom', toolbar_location='above',
-        sizing_mode=sizing_mode, x_range=x_range, **kwargs
+        sizing_mode=sizing_mode, x_range=x_range, id='bk-task-stream-plot',
+        **kwargs
     )
     fig.rect(
         x='start', y='y', width='duration', height=0.8,
@@ -93,8 +94,21 @@ def task_stream_append(lists, msg, workers, palette=task_stream_palette):
         lists['key'].append(key)
         lists['name'].append('transfer-to-' + name)
         lists['worker'].append(msg['worker'])
-        lists['color'].append('red')
-        lists['alpha'].append('0.8')
+        lists['color'].append('#FF0020')
+        lists['alpha'].append('0.4')
+        lists['worker_thread'].append(worker_thread)
+        lists['y'].append(workers[worker_thread])
+
+    if msg.get('disk_load_start') is not None:
+        start, stop = msg['disk_load_start'], msg['disk_load_stop']
+        lists['start'].append((start + stop) / 2 * 1000)
+        lists['duration'].append(1000 * (stop - start))
+
+        lists['key'].append(key)
+        lists['name'].append('disk-load-' + name)
+        lists['worker'].append(msg['worker'])
+        lists['color'].append('#FF2000')
+        lists['alpha'].append('0.4')
         lists['worker_thread'].append(worker_thread)
         lists['y'].append(workers[worker_thread])
 
@@ -103,9 +117,12 @@ def nbytes_plot(**kwargs):
     data = {'name': [], 'left': [], 'right': [], 'center': [], 'color': [],
             'percent': [], 'MB': [], 'text': []}
     source = ColumnDataSource(data)
-    fig = figure(title='Memory Use', tools='', toolbar_location=None, **kwargs)
+    fig = figure(title='Memory Use', tools='', toolbar_location=None,
+                 id='bk-nbytes-plot', **kwargs
+    )
     fig.quad(source=source, top=1, bottom=0,
-             left='left', right='right', color='color', alpha=1)
+             left='left', right='right', color='color', alpha=1
+    )
 
     fig.grid.grid_line_color = None
     fig.grid.grid_line_color = None
@@ -142,7 +159,8 @@ def progress_plot(**kwargs):
 
         y_range = Range1d(-8, 0)
         source = ColumnDataSource(data)
-        fig = figure(tools='', toolbar_location=None, y_range=y_range, **kwargs)
+        fig = figure(tools='', toolbar_location=None, y_range=y_range,
+                     id='bk-progress-plot', **kwargs)
         fig.quad(source=source, top='top', bottom='bottom',
                  left='left', right='right', color='#aaaaaa', alpha=0.2)
         fig.quad(source=source, top='top', bottom='bottom',
@@ -152,9 +170,9 @@ def progress_plot(**kwargs):
         fig.quad(source=source, top='top', bottom='bottom',
                  left='erred-loc', right='erred-loc', color='#000000', alpha=0.3)
         fig.text(source=source, text='show-name', y='bottom', x='left',
-                x_offset=5, text_font_size='10pt')
+                x_offset=5, text_font_size=value('10pt'))
         fig.text(source=source, text='done', y='bottom', x='right', x_offset=-5,
-                text_align='right', text_font_size='10pt')
+                text_align='right', text_font_size=value('10pt'))
         fig.xaxis.visible = False
         fig.yaxis.visible = False
         fig.grid.grid_line_alpha = 0
