@@ -10,7 +10,7 @@ from tornado import gen
 
 from ..http.scheduler import HTTPScheduler
 from ..utils import sync, ignoring, All
-from ..executor import Executor
+from ..client import Client
 from ..nanny import Nanny
 from ..scheduler import Scheduler
 from ..worker import Worker, _ncores
@@ -42,7 +42,7 @@ class LocalCluster(object):
     >>> c  # doctest: +SKIP
     LocalCluster("127.0.0.1:8786", workers=8, ncores=8)
 
-    >>> e = Executor(c)  # connect to local cluster  # doctest: +SKIP
+    >>> c = Client(c)  # connect to local cluster  # doctest: +SKIP
 
     Add a new worker to the cluster
     >>> w = c.start_worker(ncores=2)  # doctest: +SKIP
@@ -58,6 +58,7 @@ class LocalCluster(object):
             silence_logs=logging.CRITICAL, diagnostics_port=8787,
             services={'http': HTTPScheduler}, **kwargs):
         self.status = None
+        self.nanny = nanny
         if silence_logs:
             for l in ['distributed.scheduler',
                       'distributed.worker',
@@ -111,14 +112,22 @@ class LocalCluster(object):
     __repr__ = __str__
 
     @gen.coroutine
-    def _start_worker(self, port=0, nanny=True, **kwargs):
+    def _start_worker(self, port=0, nanny=None, **kwargs):
+        if nanny is None:
+            nanny = self.nanny
         if nanny:
             W = Nanny
+            kwargs['quiet'] = True
         else:
             W = Worker
         w = W(self.scheduler.ip, self.scheduler.port, loop=self.loop, **kwargs)
         yield w._start(port)
+
         self.workers.append(w)
+
+        while w.worker_address not in self.scheduler.worker_info:
+            yield gen.sleep(0.01)
+
         raise gen.Return(w)
 
     def start_worker(self, port=0, ncores=0, **kwargs):
@@ -209,6 +218,35 @@ class LocalCluster(object):
                 self.loop.close()
                 del self._thread
 
+    @gen.coroutine
+    def scale_up(self, n, **kwargs):
+        """ Bring the total count of workers up to ``n``
+
+        This function/coroutine should bring the total number of workers up to
+        the number ``n``.
+
+        This can be implemented either as a function or as a Tornado coroutine.
+        """
+        yield [self._start_worker(**kwargs)
+                for i in range(n - len(self.workers))]
+
+    @gen.coroutine
+    def scale_down(self, workers):
+        """ Remove ``workers`` from the cluster
+
+        Given a list of worker addresses this function should remove those
+        workers from the cluster.  This may require tracking which jobs are
+        associated to which worker address.
+
+        This can be implemented either as a function or as a Tornado coroutine.
+        """
+        workers = set(workers)
+        yield [self._stop_worker(w)
+                for w in self.workers
+                if w.worker_address in workers]
+        while workers & set(self.workers):
+            yield gen.sleep(0.01)
+
     def __del__(self):
         self.close()
 
