@@ -63,6 +63,17 @@ with ignoring(ImportError):
     default_compression = 'lz4'
 
 
+from .config import config
+default = config.get('compression', 'auto')
+if default != 'auto':
+    if default in compressions:
+        default_compression = default
+    else:
+        raise ValueError("Default compression '%s' not found.\n"
+                "Choices include auto, %s" % (
+                    default, ', '.join(sorted(map(str, compressions)))))
+
+
 BIG_BYTES_SIZE = 2**20
 BIG_BYTES_SHARD_SIZE = 2**28
 
@@ -99,8 +110,8 @@ def _extract_big_bytes(x, big, path=()):
 def dumps(msg):
     """ Transform Python value to bytestream suitable for communication """
     big = {}
-    # Only dicts can contain big values
-    if isinstance(msg, dict):
+    # Only lists and dicts can contain big values
+    if isinstance(msg, (list, dict)):
         msg, big = extract_big_bytes(msg)
     small_header, small_payload = dumps_msgpack(msg)
     if not big:
